# vs-deinterlace

> [!CAUTION]
> This package is deprecated!
> Please use https://github.com/Jaded-Encoding-Thaumaturgy/vs-jetpack instead.

### VapourSynth deinterlacing and interlaced/telecined content helper functions

<br>

For support you can check out the [JET Discord server](https://discord.gg/XTpc6Fa9eB). <br><br>

## How to install
**This package is deprecated!**

Please install https://pypi.org/p/vsjetpack instead.
